@@ -5,10 +5,12 @@
 /// 
 /// ```rust
 /// 
-/// printd!(1 + 2);
+/// use printd::printd as pd;
+/// 
+/// pd!(1 + 2);
 /// // [src/lib.rs:8] 1 + 2 = 3
 /// 
-/// printd!("Test message.");
+/// pd!("Test message.");
 /// // [src/lib.rs:12] Test message.
 /// 
 /// ```
@@ -16,6 +18,9 @@
 /// For more inforation see the readme.
 #[macro_export]
 macro_rules! printd {
+    () => {
+        println!("[{}:{}]", file!(), line!());
+    };
     ($message:literal) => {
         println!("[{}:{}] {:?}", file!(), line!(), $message);
     };
@@ -36,6 +41,9 @@ macro_rules! printd {
 /// Works just like `printd`.
 #[macro_export]
 macro_rules! eprintd {
+    () => {
+        println!("[{}:{}]", file!(), line!());
+    };
     ($message:literal) => {
         eprintln!("[{}:{}] {:?}", file!(), line!(), $message);
     };
